@@ -6,11 +6,13 @@
  */
 package paraselene.dyna;
 
+import java.io.*;
+
 /**
  * DynamicPage構築時のURI解決。
  * 解析中にURIを示す属性値が登場するとコールされます。
  */
-public interface URIResolver {
+public interface URIResolver extends Serializable {
 	/**
 	 * URI解決。次のようなものが呼び出されます。
 	 * <ul>
