@@ -86,23 +86,28 @@ public abstract class Supervisor extends HttpServlet {
 	private static String resolvePage( ServerInformation holder, Page from, String p, int from_key, int to_key ) {
 		try {
 			URI	u = new URI( p );
-			PageID	from_page = from.getID();
+			PageID	from_page = null;
+			if ( from != null ) {
+				from_page = from.getID();
+			}
 			PageID	to = null;
-			Page	page = from_page.getPageFactory().getPage(
+			Page	page = holder.getPageFactory().getPage(
 				Integer.parseInt( u.getPath().substring( LINK_LEN[0] ) )
 			);
 			if ( page != null ) {
 				to = page.getID();
 				to.getPageFactory().returnPage( page );
 			}
-			Page	parent = from.getParentPage();
-			if ( from != parent ) {
-				if ( from_page == to ) {
-					page = parent;
-					from_page = to = parent.getID();
-				}
-				else {
-					from_page = parent.getID();
+			if ( from != null ) {
+				Page	parent = from.getParentPage();
+				if ( from != parent ) {
+					if ( from_page == to ) {
+						page = parent;
+						from_page = to = parent.getID();
+					}
+					else {
+						from_page = parent.getID();
+					}
 				}
 			}
 			if ( to != null ) {
