@@ -86,11 +86,23 @@ public class Tag extends HTMLPart {
 
 	private boolean modify_enable = true;
 
+	private static final String[] ERR_IE = new String[] {
+		"table", "thead", "tbody", "tfoot", "tr"
+	};
+
+	private boolean isTable() {
+		String	name = getName();
+		for ( int i = 0; i < ERR_IE.length; i++ ) {
+			if ( ERR_IE[i].equals( name ) )	return true;
+		}
+		return false;
+	}
+
 	/**
 	 * フレームワークが使用します。
 	 */
 	protected void setModifyMyselef() {
-		if ( getAttribute( "id" ) == null ) {
+		if ( getAttribute( "id" ) == null || isTable() ) {
 			Tag	out = getOuterTag();
 			if ( out != null ) {
 				out.setModifyMyselef();
@@ -384,7 +396,16 @@ public class Tag extends HTMLPart {
 		at.setAssignedTag( this );
 		if ( "name".equals( at_name ) ) {
 			Tag	out = getOuterTag();
-			if ( out != null )	out.makeID();
+			while ( out != null ) {
+				if ( out.isTable() ) {
+					out = out.getOuterTag();
+					continue;
+				}
+				break;
+			}
+			if ( out != null ) {
+				out.makeID();
+			}
 		}
 	}
 
