@@ -26,15 +26,24 @@ public class Table extends Tag {
 	 * テーブル整合性エラー。
 	 */
 	public class TableException extends Exception {
-		TableException( String mes ) {
+		private Table table;
+		TableException( String mes, Table t ) {
 			super( mes );
+			table = t;
+		}
+		/**
+		 * 例外が発生したテーブルを返します。
+		 * @return テーブル。
+		 */
+		public Table getTable() {
+			return table;
 		}
 	}
 
 	private int seekFree( Column[] dim, int start, int y ) throws TableException {
 		for ( ; ; start++ )	{
 			if ( start >= dim.length ) {
-				throw new TableException( String.format( "%d行が不正", y ) );
+				throw new TableException( String.format( "%d行が不正", y ), this );
 			}
 			if ( map[y][start] == null )	return start;
 		}
@@ -79,7 +88,7 @@ public class Table extends Tag {
 		for ( int i = 0; i < map_y; i++ ) {
 			for ( int j = 0; j < map_x; j++ ) {
 				if ( map[i][j] == null ) {
-					throw new TableException( String.format( "不正な行あり[%d,%d]=null", j, i ) );
+					throw new TableException( String.format( "不正な行あり[%d,%d]=null", j, i ), this );
 				}
 			}
 		}
@@ -141,7 +150,8 @@ public class Table extends Tag {
 		makeMap();
 		if ( x < 0 || y < 0 || x >= map_x || y >= map_y ) {
 			throw new TableException(
-				String.format( "x=%d, y=%d 番号が範囲を超えています。", x, y )
+				String.format( "x=%d, y=%d 番号が範囲を超えています。", x, y ),
+				this
 			);
 		}
 		return map[y][x];
@@ -162,7 +172,8 @@ public class Table extends Tag {
 		ArrayList<HTMLPart>	list = new ArrayList<HTMLPart>();
 		if ( y < 0 || y >= map_y ) {
 			throw new TableException(
-				String.format( "y=%d 番号が範囲を超えています。", y )
+				String.format( "y=%d 番号が範囲を超えています。", y ),
+				this
 			);
 		}
 		for ( int x = 0; x < map_x; x++ ) {
@@ -189,7 +200,8 @@ public class Table extends Tag {
 		makeMap();
 		if ( y < 0 || y >= map_y ) {
 			throw new TableException(
-				String.format( "y=%d 番号が範囲を超えています。", y )
+				String.format( "y=%d 番号が範囲を超えています。", y ),
+				this
 			);
 		}
 		for ( int x = 0; x < map_x; x++ ) {
